@@ -281,26 +281,35 @@ def upload(connection_or_endpoint, image_id, image_file, key,
             connection.delete_image(image_id)
             raise ValueError(f'failed to link image {image_id} to project {project}') from e
 
-        if destination is local_proxy:
-            # spin up a local WebHDFS-like server, passing data along to connection.upload_image, while passing any
-            # named values generated from the image tool to the caller
+        try:
+            if destination is local_proxy:
+                # spin up a local WebHDFS-like server, passing data along to connection.upload_image, while passing any
+                # named values generated from the image tool to the caller
 
-            # define a wrapper around connection.upload_image to force the callback to be authenticated
-            # an upload_image call potentially needs a data source that can't be reused, so make sure that any
-            # potential forced re-auth happens on a repeatable call
-            def force_auth_upload_callback(*args, **kwargs):
-                # call the identity_uid function to avoid the cached identity, make the remote tell us who we are
-                connection.identity_uid()
-                # now call the actual callback we intended to call before
-                return connection.upload_image(*args, **kwargs)
+                # define a wrapper around connection.upload_image to force the callback to be authenticated
+                # an upload_image call potentially needs a data source that can't be reused, so make sure that any
+                # potential forced re-auth happens on a repeatable call
+                def force_auth_upload_callback(*args, **kwargs):
+                    # call the identity_uid function to avoid the cached identity, make the remote tell us who we are
+                    connection.identity_uid()
+                    # now call the actual callback we intended to call before
+                    return connection.upload_image(*args, **kwargs)
 
-            with WebHDFSServer(force_auth_upload_callback,
-                               bufsize=bufsize, max_retries=max_retries, retry_wait=retry_wait,
-                               streaming=streaming) as server:
-                yield from run_image_tool('http://localhost:{}/'.format(server.server_port), uploaded_image)
-        else:
-            # pass any named values generated from the image tool to the caller (image tool uploads the data itself)
-            yield from run_image_tool(destination, uploaded_image)
+                with WebHDFSServer(force_auth_upload_callback,
+                                   bufsize=bufsize, max_retries=max_retries, retry_wait=retry_wait,
+                                   streaming=streaming) as server:
+                    yield from run_image_tool('http://localhost:{}/'.format(server.server_port), uploaded_image)
+            else:
+                # pass any named values generated from the image tool to the caller (image tool uploads the data itself)
+                yield from run_image_tool(destination, uploaded_image)
+        except (KeyboardInterrupt, BrokenPipeError):
+            # The user aborted the upload, or the upload has failed due to a broken pipe error
+            log.warn('upload was interrupted, removing partially uploaded image {}', image_id)
+            if project:
+                connection.unlink_image(project, image_id)
+            connection.delete_image(image_id)
+            log.warn('partial upload removed')
+            raise
 
         if uploaded_image != created_image:
             # image metadata was changed during upload, reflect changes to remote
